@@ -3,8 +3,59 @@ import itertools
 import typing as tp
 import warnings
 
+from ..recast_exceptions import silence_excs
+from ..decorators import for_argument
+
 T, U = tp.TypeVar('T'), tp.TypeVar('U')
 
+IteratorOrIterable = tp.Union[tp.Iterator[T], tp.Iterable[T]]
+
+
+@for_argument(iter)
+def even(sq: IteratorOrIterable) -> tp.Iterator[T]:
+    """
+    Return only elements with even indices in this iterable (first element will be returned,
+    as indices are counted from 0)
+    """
+    try:
+        while True:
+            yield next(sq)
+            next(sq)
+    except StopIteration:
+        return
+
+
+@for_argument(iter)
+def odd(sq: IteratorOrIterable) -> tp.Iterator[T]:
+    """
+    Return only elements with odd indices in this iterable.
+    """
+    try:
+        while True:
+            next(sq)
+            yield next(sq)
+    except StopIteration:
+        return
+
+
+def count(sq: IteratorOrIterable, start: tp.Optional[int] = None, step: int = 1) -> tp.Iterator[int]:
+    """
+    Return a sequence of integers, for each entry in the sequence with provided step.
+
+    Essentially the same (if step were ignored) as:
+
+    >>> (i for i, x in enumerate(sq, start=start_at))
+
+    :param sq: sequence to enumerate
+    :param start: alias for start_at. Prefer it in regards to start_at
+    :param step: number to add to internal counter after each element
+    :return: an iterator of subsequent integers
+    """
+    num = start
+    for _ in sq:
+        yield num
+        num += step
+
 
 def iter_dict_of_list(dct: tp.Dict[T, tp.List[U]]) -> tp.Generator[tp.Tuple[T, U], None, None]:
     """
@@ -40,11 +91,6 @@ def is_instance(classes: tp.Union[tp.Tuple[type, ...], type]) -> tp.Callable[[ob
     return inner
 
 
-T = tp.TypeVar('T')
-
-IteratorOrIterable = tp.Union[tp.Iterator[T], tp.Iterable[T]]
-
-
 def other_sequence_no_longer_than(base_sequence: IteratorOrIterable,
                                   other_sequence: IteratorOrIterable[T]) -> tp.Iterator[T]:
     """
